summaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/engine/bank03.asm16
-rw-r--r--src/engine/bank04.asm2
-rw-r--r--src/macros/scripts.asm8
3 files changed, 13 insertions, 13 deletions
diff --git a/src/engine/bank04.asm b/src/engine/bank04.asm
index 4e92876..bb4340e 100644
--- a/src/engine/bank04.asm
+++ b/src/engine/bank04.asm
@@ -1052,7 +1052,7 @@ OverworldScriptTable: ; 1217b (4:617b)
dw ScriptCommand_LoadActiveNPCNameIntoTxRamSlot
dw ScriptCommand_StartChallengeHallDuel
dw ScriptCommand_PrintTextForChallengeCup
- dw ScriptCommand_MoveWramNPC
+ dw ScriptCommand_MoveChallengeHallNPC
dw ScriptCommand_UnloadChallengeHallNPC
dw ScriptCommand_SetChallengeHallNPCCoords
dw ScriptCommand_PickChallengeHallOpponent
diff --git a/src/engine/bank03.asm b/src/engine/bank03.asm
index b97d49f..14220b5 100644
--- a/src/engine/bank03.asm
+++ b/src/engine/bank03.asm
@@ -2116,9 +2116,9 @@ ScriptCommand_MoveActiveNPC: ; ce4a (3:4e4a)
ld [wLoadedNPCTempIndex], a
jr ExecuteNPCMovement
; Begin a series of NPC movements on an arbitrary NPC
; based on the series of directions pointed to by bc
-ScriptCommand_MoveWramNPC: ; ce52 (3:4e52)
+ScriptCommand_MoveChallengeHallNPC: ; ce52 (3:4e52)
ld a, [wLoadedNPCTempIndex]
push af
ld a, [wTempNPC]
@@ -7791,13 +7791,13 @@ Script_WonAtChallengeHall: ; f441 (3:7441)
load_active_npc_name_into_txram_slot $00
print_npc_text Text053e
close_text_box
- move_wram_npc NPCMovement_f4c8
+ move_challenge_hall_npc NPCMovement_f4c8
unload_challenge_hall_npc
print_npc_text Text053f
close_text_box
pick_challenge_hall_opponent
set_challenge_hall_npc_coords 20, 20
- move_wram_npc NPCMovement_f4d0
+ move_challenge_hall_npc NPCMovement_f4d0
load_active_npc_name_into_txram_slot $00
jump_if_flag_equal EVENT_FLAG_45, $02, NULL
print_variable_npc_text Text0540, Text0541
@@ -7865,18 +7865,18 @@ Script_f4db: ; f4db (3:74db)
set_dialog_npc NPC_RONALD1
jump_if_flag_equal EVENT_FLAG_44, $01, NULL
print_variable_npc_text Text054c, Text054d
- move_wram_npc NPCMovement_f4d8
+ move_challenge_hall_npc NPCMovement_f4d8
do_frames 40
- move_wram_npc NPCMovement_f34c
+ move_challenge_hall_npc NPCMovement_f34c
jump_if_flag_equal EVENT_FLAG_44, $01, NULL
print_variable_npc_text Text054e, Text054f
set_dialog_npc NPC_HOST
close_text_box
- move_wram_npc NPCMovement_f4c9
+ move_challenge_hall_npc NPCMovement_f4c9
script_jump .ows_f516
.ows_f513
- move_wram_npc NPCMovement_f4c8
+ move_challenge_hall_npc NPCMovement_f4c8
.ows_f516
unload_challenge_hall_npc
move_active_npc NPCMovement_f383
@@ -2116,9 +2116,9 @@ ScriptCommand_MoveActiveNPC: ; ce4a (3:4e4a)
ld [wLoadedNPCTempIndex], a
jr ExecuteNPCMovement
-; Begin a series of NPC movements on an arbitrary NPC
+; Begin a series of NPC movements on the Challenge Hall opponent NPC
; based on the series of directions pointed to by bc
diff --git a/src/macros/scripts.asm b/src/macros/scripts.asm
index 25c2ae1..828d5d4 100644
--- a/src/macros/scripts.asm
+++ b/src/macros/scripts.asm
@@ -52,7 +52,7 @@ ENDM
const ScriptCommand_LoadActiveNPCNameIntoTxRamSlot_index ; $2c
const ScriptCommand_StartChallengeHallDuel_index ; $2d
const ScriptCommand_PrintTextForChallengeCup_index ; $2e
- const ScriptCommand_MoveWramNPC_index ; $2f
+ const ScriptCommand_MoveChallengeHallNPC_index ; $2f
const ScriptCommand_UnloadChallengeHallNPC_index ; $30
const ScriptCommand_SetChallengeHallNPCCoords_index ; $31
const ScriptCommand_PickChallengeHallOpponent_index ; $32
@@ -421,9 +421,9 @@ print_text_for_challenge_cup: MACRO
tx \3 ; Text Pointer for Challenge Cup #3
ENDM
-; Moves the NPC in wTempNPC using an NPCMovement
-move_wram_npc: MACRO
- run_command ScriptCommand_MoveWramNPC
+; Moves the Challenge Hall opponent NPC using an NPCMovement
+move_challenge_hall_npc: MACRO
+ run_command ScriptCommand_MoveChallengeHallNPC
dw \1 ; NPCMovement (ex NPCMovement_d880)
ENDM